import { type Ref } from "vue";
import type { AxiosInstance } from "axios";
import type { RequestConfig, HttpClientConfig, ErrorResponse, OnStartHandler, OnSuccessHandler, OnErrorHandler } from "./types";
export declare class HttpClientError extends Error implements ErrorResponse {
    code: number;
    exception: Error;
    data?: object;
    constructor(response: ErrorResponse);
}
export declare class HttpClient {
    CODE_NETWORK_ERROR: number;
    CODE_UNKNOWN_ERROR: number;
    private axios;
    private processCounter;
    private config;
    constructor(axios: AxiosInstance, config?: HttpClientConfig);
    get<T>(config: RequestConfig): Promise<T>;
    post<T>(config: RequestConfig): Promise<T>;
    put<T>(config: RequestConfig): Promise<T>;
    patch<T>(config: RequestConfig): Promise<T>;
    delete<T>(config: RequestConfig): Promise<T>;
    request<T>(config: RequestConfig): Promise<T>;
    attachCounter(counter: Ref<number>): void;
    onStart(handler: OnStartHandler): void;
    onSuccess(handler: OnSuccessHandler): void;
    onError(handler: OnErrorHandler): void;
    private specifyMethod;
    private handleStart;
    private handleSuccess;
    private handleError;
    private needAffectCounter;
    private handle;
}
